@@ -920,4 +920,15 @@ $(function() {
 		});
 	});
 
+	$(document).on('action-spell-check', function() {
+		var editor = GetCurrentEditor();
+		window.sendMessage('spell-check', {source: editor.getValue()}, function(result) {
+			if(result.error) {
+				editor.setValue(result.source);
+			} else {
+				alert("No result");
+			}
+		});
+	});
+
 });
